Skip to contents

A data frame with the names, abbreviations, and expressions of the distance metrics implemented in the package.

Usage

data(distances)

Format

A data frame with 5 columns and 10 rows.

See also

Other distances: distance(), distance_matrix()