Skip to contents

Default Block Size for Restricted Permutation in Dissimilarity Analyses

Usage

utils_block_size(tsl = NULL, block_size = NULL)

Arguments

tsl

(required, list) Time series list. Default: NULL.

block_size

(optional, integer vector) Row block sizes for restricted permutation tests. Used only when the permutation method is "restricted" or "restricted_by_row". A block of size n indicates that a row can only be permuted within a block of n adjacent rows. If NULL, defaults to 20 percent of the rows of the shortest time series in tsl. Minimum value is 2; maximum value is 50 percent of the rows of the shortest time series in tsl. Default: NULL.

Value

An integer.