Coerce Coredata of Univariate Zoo Time Series to Matrix
Source:R/zoo_vector_to_matrix.R
zoo_vector_to_matrix.RdTransforms vector coredata of univariate zoo time series to class matrix. If the input zoo time series has the attribute "name", the output inherits the value of such attribute.
Multivariate zoo objects (those with multiple columns) are returned unchanged.
See also
Other zoo_functions:
zoo_aggregate(),
zoo_name_clean(),
zoo_name_get(),
zoo_name_set(),
zoo_permute(),
zoo_plot(),
zoo_resample(),
zoo_smooth_exponential(),
zoo_smooth_window(),
zoo_time(),
zoo_to_tsl()