Default Block Size for Restricted Permutation in Dissimilarity Analyses
Source:R/utils_block_size.R
utils_block_size.RdDefault Block Size for Restricted Permutation in Dissimilarity Analyses
Arguments
- tsl
(required, list) Time series list. Default: NULL.
- block_size
(optional, integer vector) Row block sizes for restricted permutation tests. Used only when the permutation method is "restricted" or "restricted_by_row". A block of size
nindicates that a row can only be permuted within a block ofnadjacent rows. If NULL, defaults to 20 percent of the rows of the shortest time series intsl. Minimum value is 2; maximum value is 50 percent of the rows of the shortest time series intsl. Default: NULL.
See also
Other distantia_support:
distantia_aggregate(),
distantia_boxplot(),
distantia_cluster_hclust(),
distantia_cluster_kmeans(),
distantia_matrix(),
distantia_model_frame(),
distantia_spatial(),
distantia_stats(),
distantia_time_delay(),
utils_cluster_hclust_optimizer(),
utils_cluster_kmeans_optimizer(),
utils_cluster_silhouette()