Returns a data frame with the names of the supported time units, the classes that can handle each time unit, and the threshold used to identify which time units can be used when aggregating a time series.
See also
Other internal_time_handling:
utils_as_time(),
utils_coerce_time_class(),
utils_is_time(),
utils_new_time(),
utils_time_keywords(),
utils_time_keywords_dictionary(),
utils_time_keywords_translate()
Examples
df <- utils_time_units()
head(df)
#> base_units units Date POSIXct numeric integer
#> 1 days millennia TRUE TRUE FALSE FALSE
#> 2 days centuries TRUE TRUE FALSE FALSE
#> 3 days decades TRUE TRUE FALSE FALSE
#> 4 days years TRUE TRUE FALSE FALSE
#> 5 days quarters TRUE TRUE FALSE FALSE
#> 6 days months TRUE TRUE FALSE FALSE